{ config, pkgs, ... }:
{
  # Enable OpenGL
  # Load nvidia driver for Xorg and Wayland
  environment.pathsToLink = [ "/libexec" ];

  # Bootloader.
  boot.loader.systemd-boot.enable = true;
  boot.loader.efi.canTouchEfiVariables = true;
  boot = {
    extraModulePackages = with config.boot.kernelPackages; [ acpi_call ];
    kernelModules = [ "acpi_call" ];
    kernelPackages = pkgs.linuxPackages_xanmod_latest;
  };
  boot.kernel.sysctl = {
    "vm.max_map_count" = 16777216;
    "fs.file-max" = 524288;
  };



  networking.hostName = "zedd"; # Define your hostname.
  networking.networkmanager.enable = true;
  time.timeZone = "Europe/Oslo";
  i18n.defaultLocale = "en_US.UTF-8";

  environment.sessionVariables = rec {
    XDG_CACHE_HOME = "$HOME/.cache";
    XDG_CONFIG_HOME = "$HOME/.config";
    XDG_DATA_HOME = "$HOME/.local/share";
    XDG_STATE_HOME = "$HOME/.local/state";
    XDG_BIN_HOME = "$HOME/.local/bin";
    PATH = [ "${XDG_BIN_HOME}" ];

  };
  fileSystems."/data" = {
    device = "/dev/data/data";
    fsType = "ext4";
  };
  xdg.portal =
    {
      enable = true;
      xdgOpenUsePortal = true;
      config = {
        common = {
          default = [
            "*"
          ];
        };
      };
      extraPortals = (with pkgs; [
        # unstable.xdg-desktop-portal-hyprland
        xdg-desktop-portal-gtk
      ]);

    };

  # Allow unfree packages
  nixpkgs.config.allowUnfree = true;
  nix.settings.experimental-features = [ "nix-command" "flakes" ];
  nix.settings = {
    substituters = [ "https://nix-gaming.cachix.org" ];
    trusted-public-keys = [ "nix-gaming.cachix.org-1:nbjlureqMbRAxR1gJ/f3hxemL9svXaZF/Ees8vCUUs4=" ];
  };
  virtualisation.docker.enable = true;
  virtualisation.docker.liveRestore = false;
  system.stateVersion = "23.11"; # Did you read the comment?

}
