{ pkgs, inputs, user, ... }: {
  imports = [ inputs.home-manager.nixosModules.home-manager ];
  home-manager = {
    useUserPackages = true;
    useGlobalPkgs = true;
    extraSpecialArgs = { inherit pkgs inputs user; };
    users.${user} = { pkgs, ... }: {
      imports = [
        inputs.sops-nix.homeManagerModules.sops
        ./sops
        ./programs/neovim
        ./programs/firefox
        ./programs/tmux
        ./programs/dunst
        ./programs/rofi
        ./programs/obs-studio
        ./programs/vscode
        ./programs/games
        ./scripts
        ./zsh
        ./packages
        ./ssh
        ./services/ssh-office.nix
        ./services/gnome-keyring.nix
      ];
      tmux.enable = true;
      firefox.enable = true;
      xdg.enable = true;
      services.picom = {
        enable = true;
        settings = {
          unredir-if-possible = false;
          backend = "xrender"; # try "glx" if xrender doesn't help
          vsync = true;
        };
      };
      home = {
        username = "${user}";
        homeDirectory = "/home/${user}";
        stateVersion = "23.11";
      };
      programs.home-manager.enable = true;
    };
  };
}
